@@ -12,13 +12,7 @@ checkInternet <- function(site = "www.r-project.org") {
 }
 checkInternet()
 
-# Only run all tests if using a development version (which has 4 components,
-# e.g. 0.0.0.1). CRAN releases have the standard 3 component version. This
-# prevents spurious errors due to websites changing how they serve their
-# favicon.
-version <- utils::packageVersion("faviconPlease")
-home <- length(unclass(version)[[1]]) == 4
-
 if (requireNamespace("tinytest", quietly = TRUE)){
-  tinytest::test_package("faviconPlease", at_home = home)
+  tinytest::test_package("faviconPlease", at_home = FALSE)
 }
+# To run the at_home tests, run tinytest::test_all()
